@@ -39,3 +39,11 @@ def boxify(use_snakes: Optional[bool] = False,
         return _impl
 
     return _boxify
+
+
+def truncate_string(unicode_str: str, max_size: int) -> str:
+    str_bytes = unicode_str.encode("utf-8")
+    if len(str_bytes) < max_size:
+        return unicode_str  # keep the original string
+    else:
+        return str_bytes[:max_size].decode("utf-8", errors="ignore")
