@@ -15,7 +15,7 @@ if __name__ == '__main__':
 
     headers = {'x-mcd-id': api_id, 'x-mcd-token': api_token}
     endpoint = RequestsEndpoint(url=args.url, base_headers=headers)
-    data = endpoint(query, variables(include_description=True, include_deprecated=False))
+    data = endpoint(query, variables(include_description=True, include_deprecated=True))
 
     if data.get('errors'):
         raise SystemExit(f"Failed to retrieve schema with - {data.get('errors')}")
